@@ -17,7 +17,7 @@
 #ifndef BUGREPORTADDRESS_H
 #define BUGREPORTADDRESS_H
 
-#include <QtCore/QString>
+#include <QString>
 
 #include "drkonqi_globals.h"
 
@@ -36,7 +36,7 @@ public:
 
     inline bool isEmail() const
     {
-        return contains('@');
+        return contains(QLatin1Char('@'));
     }
 };
 
